# ------------------------------------------------------------------------------
# Copyright (c) 2018 Semiconductor Components Industries, LLC (d/b/a ON
# Semiconductor), All Rights Reserved
#
# This code is the property of ON Semiconductor and may not be redistributed
# in any form without prior written permission from ON Semiconductor.
# The terms of use and warranty for this code are covered by contractual
# agreements between ON Semiconductor and the licensee.
# ------------------------------------------------------------------------------
#  dtm_test_execution.py
#    - Example code which utilizes the dtm library to run the Direct Test Mode
#      tests for E7160
# ------------------------------------------------------------------------------

import dtm_lib_modified as dtm


def main():
    '''
    General setup required to enter DTM - DO NOT REMOVE - edit the following as necessary:
        - LTCOM: Change this if the Lower Tester COM port is known. Otherwise it will prompt you to select a port.
        - Baud_Rate: Do not edit this unless there is a firmware update to the hci_app that requires this to be changed.
        - Logging: Setting this to 1 enables logging.
    '''
    settings = {'LTCOM'     : -1,
                'Baud_Rate' : 9600,
                'Logging'   : 1,
                'Programmer': 'CAA'}
    # Create test_runner instance, puts E7160 into Direct Test Mode
    test_runner = dtm.TestMaster(settings)

    '''
    Configurable Test Execution
    These tests can be run in any order, as many times, and with any appropriate combination of parameters. The test
    results are given on the console for each test run.
    Function signature:
        test_runner.test(test_type, payload_type, phy_type, packet_length, channel, test_time)
    Function parameters:
        - test_type:        The type of test being run (transmit or receive). See dtm.Test_Type for options.
        - payload_type:     The string of bits that will be sent. See dtm.Payload_Type class for options.
        - phy_type:         The physical transmission speed being used. See dtm.PHY_Type for options.
        - packet_length:    length of bytes to send as data per packet. Varies from 1 to 255, but should be 37 as
                            indicated in the BLE standard.
        - channel:          The logical channel being used to transmit data. Varies from 0 to 39.
        - test_time:        The time in seconds for the test to run. This can vary from 0 to 40, as specified by the
                            BLE standard.
    
    Note: TX tests will be more accurate as they use information from the radio on E7160 itself to find out the number
    of packets transmitted, and compare it the the number of packets received. RX tests on the other hand have to use
    timing calculations to estimate the number of packets being sent when comparing to number of packets being received.
    '''
    # Repeatable Test instruction
    test_runner.test(dtm.Test_Type.TX_Test, dtm.Payload_Type.PRBS9, dtm.PHY_Type.LE_2M, 37, 0, 3)

    test_runner.test(dtm.Test_Type.RX_Test, dtm.Payload_Type.All_Ones, dtm.PHY_Type.LE_2M, 37, 0, 3)

    test_runner.test(dtm.Test_Type.TX_Test, dtm.Payload_Type.One_Zero_Alternating, dtm.PHY_Type.LE_1M, 37, 0, 3)

    test_runner.test(dtm.Test_Type.RX_Test, dtm.Payload_Type.PRBS9, dtm.PHY_Type.LE_1M, 37, 6, 3)

    # Return E7160 back to a normal working state
    test_runner.exit_DTM()



if __name__ == '__main__':
    main()
